<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Помилковий вираз</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark Theme</source>
        <translation>Темна тема</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Простий режим</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Науковий режим</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Калькулятор Deepin</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepin Калькулятор це простий і зручний настільний калькулятор. Він підтримує додавання, віднімання, множення і ділення.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Помилковий вираз</translation>
    </message>
</context>
</TS>